Struct ZwlrInputInhibitManagerV1
pub struct ZwlrInputInhibitManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
inhibits input events to other clients
Clients can use this interface to prevent input events from being sent to any surfaces but its own, which is useful for example in lock screen software. It is assumed that access to this interface will be locked down to whitelisted clients by the compositor.
Note! This protocol is deprecated and not intended for production use. For screen lockers, use the ext-session-lock-v1 protocol.
See also the Request enum for this interface.